@@ -17,8 +17,7 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2006, Lehigh University, Yan Xu, and Ted Ralphs.       *
- * Corporation, Lehigh University, Yan Xu, Ted Ralphs, Matthew Salzman and   *
+ * Copyright (C) 2001-2008, Lehigh University, Yan Xu, and Ted Ralphs.       *
  *===========================================================================*/
 
 #ifndef AbcModel_h_
@@ -230,7 +229,7 @@ class AbcModel : public AlpsModel {
 	    init();
 	    solver_ = rhs.clone();
 	    ourSolver_ = true ;
-	    continuousSolver_ = NULL;
+	    continuousSolver_ = 0;
 	    int numberColumns = solver_->getNumCols();
 	    int iColumn;
 	    if (numberColumns) {
@@ -364,6 +363,8 @@ class AbcModel : public AlpsModel {
 	    pseudoList_ = NULL;
 	    pseudoIndices_ = NULL;
 	    
+	    continuousSolver_ = 0;
+
 	    // Set values for parameters
 	    intParam_[AbcMaxNumNode] = 9999999;
 	    intParam_[AbcMaxNumSol] = 9999999;
@@ -947,7 +948,7 @@ class AbcModel : public AlpsModel {
 	}
 
     /// Priorities
-    inline const int * priority() const { return priority_;};
+    inline const int * priority() const { return priority_;}
 
     /// Returns priority level for an object (or 1000 if no priorities exist)
     inline int priority(int sequence) const
@@ -956,7 +957,7 @@ class AbcModel : public AlpsModel {
 		return priority_[sequence];
 	    else
 		return 1000;
-	};
+	}
     
     /** The method that encodes the model into a encoded object. */
     virtual AlpsEncoded* encode() const;
