@@ -17,8 +17,7 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2006, Lehigh University, Yan Xu, and Ted Ralphs.       *
- * Corporation, Lehigh University, Yan Xu, Ted Ralphs, Matthew Salzman and   *
+ * Copyright (C) 2001-2008, Lehigh University, Yan Xu, and Ted Ralphs.       *
  *===========================================================================*/
 
 #include <cassert>
@@ -54,8 +53,8 @@ static double checkInfeasibility(AbcModel* model, const int columnNumber,
     const double * lower = solver->getColLower();
     const double * upper = solver->getColUpper();
     double value = solution[columnNumber];
-    value = max(value, lower[columnNumber]);
-    value = min(value, upper[columnNumber]);
+    value = std::max(value, lower[columnNumber]);
+    value = std::min(value, upper[columnNumber]);
     /*printf("%d %g %g %g %g\n",columnNumber_,value,lower[columnNumber_],
     solution[columnNumber_],upper[columnNumber_]);*/
     double nearest = floor(value + 0.5);
@@ -134,7 +133,7 @@ AbcTreeNode::process(bool isRoot, bool rampUp)
     assert(nodeInterval > 0);
 
     if(m->getNodeCount() % nodeInterval == 0){
-	const int nodeLeft = getKnowledgeBroker()->getNumNodesLeft();
+	const int nodeLeft = getKnowledgeBroker()->updateNumNodesLeft();
 	m->messageHandler()->message(ABC_STATUS, m->messages())
 	    << getKnowledgeBroker()->getProcRank() << (m->getNodeCount()) 
 	    << nodeLeft <<  m->getCutoff() << parentObjValue << CoinMessageEol;
@@ -181,7 +180,7 @@ AbcTreeNode::process(bool isRoot, bool rampUp)
 	AbcSolution* sol = new AbcSolution(numCols, 
 					   m->bestSolution(),
 					   m->getObjValue());
-	getKnowledgeBroker()->addKnowledge(ALPS_SOLUTION, sol, 
+	getKnowledgeBroker()->addKnowledge(AlpsKnowledgeTypeSolution, sol, 
 					   m->getObjValue());
     }
     
@@ -214,7 +213,8 @@ AbcTreeNode::process(bool isRoot, bool rampUp)
 		AbcSolution* ksol = new AbcSolution(numCols, 
 						    m->getColSolution(), 
 						    val);
-		getKnowledgeBroker()->addKnowledge(ALPS_SOLUTION, ksol, val); 
+		getKnowledgeBroker()->addKnowledge(AlpsKnowledgeTypeSolution, 
+						   ksol, val); 
 	    }
 	    setStatus(AlpsNodeStatusFathomed);
 	}
@@ -234,8 +234,8 @@ AbcTreeNode::process(bool isRoot, bool rampUp)
 			AbcSolution *sol = new AbcSolution(numCols, 
 							   m->bestSolution(),
 							   m->getObjValue());
-			getKnowledgeBroker()->addKnowledge(ALPS_SOLUTION, sol, 
-							   m->getObjValue());
+			getKnowledgeBroker()->addKnowledge(
+                           AlpsKnowledgeTypeSolution, sol, m->getObjValue());
 			
 		    }	
 		    if (action == -1) { 
@@ -414,7 +414,7 @@ AbcTreeNode::encode() const
 #if defined(ABC_DEBUG_MORE)
     std::cout << "AbcTreeNode::encode()--start to encode" << std::endl;
 #endif
-    AlpsEncoded* encoded = new AlpsEncoded("ALPS_NODE");
+    AlpsEncoded* encoded = new AlpsEncoded(AlpsKnowledgeTypeNode);
     AbcNodeDesc* desc = dynamic_cast<AbcNodeDesc*>(desc_);
     AbcModel* model = dynamic_cast<AbcModel*>(desc->getModel());
 
@@ -585,7 +585,7 @@ int AbcTreeNode::chooseBranch(AbcModel *model, bool& strongFound)
     bool beforeSolution = model->getSolutionCount()==0;
     int numberStrong = model->numberStrong();
     int numberObjects = model->numberIntegers();
-    int maximumStrong = max(min(model->numberStrong(), numberObjects), 1);
+    int maximumStrong = std::max(std::min(model->numberStrong(), numberObjects), 1);
     int numberColumns = model->getNumCols();
     double * saveUpper = new double[numberColumns];
     double * saveLower = new double[numberColumns];
@@ -674,7 +674,7 @@ int AbcTreeNode::chooseBranch(AbcModel *model, bool& strongFound)
 		choice[iSmallest].downMovement = otherWay;
 		saveOtherWay = otherWay;
 		choice[iSmallest].possibleBranch = object;
-		numberStrong = max(numberStrong, iSmallest + 1);
+		numberStrong = std::max(numberStrong, iSmallest + 1);
 		choice[iSmallest].objectNumber = i;
 		int j;
 		iSmallest = -1;
@@ -1000,7 +1000,7 @@ int AbcTreeNode::chooseBranch(AbcModel *model, bool& strongFound)
 		averageCostPerIteration += choice[i].downMovement +
 		    choice[i].upMovement;
 		smallestNumberInfeasibilities = 
-		    min(min(choice[i].numIntInfeasDown,
+		    std::min(std::min(choice[i].numIntInfeasDown,
 			    choice[i].numIntInfeasUp),
 			smallestNumberInfeasibilities);
 	    }
@@ -1096,8 +1096,7 @@ int AbcTreeNode::chooseBranch(AbcModel *model, bool& strongFound)
 	    pseudoC = model->getPseudoList()[object];
 	    upCost = pseudoC->upCost_ * (1.0 - fraction);
 	    downCost = pseudoC->downCost_ * fraction;
-	    deg = 4.0 * std::min(upCost, downCost) +
-		1.0 * std::max(upCost, downCost);
+	    deg = 4.0 * std::min(upCost, downCost) + 1.0 * std::max(upCost, downCost);
 	    if (deg > mostDeg) {
 		mostDeg = deg;
 		mostInd = object;
