@@ -17,7 +17,7 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2007, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * Copyright (C) 2001-2009, Lehigh University, Yan Xu, and Ted Ralphs.       *
  *===========================================================================*/
 
 #ifndef AlpsKnowledgeBrokerMPI_h_
@@ -189,9 +189,6 @@ class AlpsKnowledgeBrokerMPI : public AlpsKnowledgeBroker {
 
     /** To record how many nodes processed for each hub */
     int* hubNodeProcesseds_;
-
-    /** To record how many nodes processed by the system. */
-    int systemNodeProcessed_;
     //@}
 
     /** @name Message counts
@@ -304,7 +301,7 @@ class AlpsKnowledgeBrokerMPI : public AlpsKnowledgeBroker {
 
     /** Temporily halt search */
     int haltSearch_;
-    
+
  protected:
 
     /** Initialize member data. */
@@ -370,6 +367,9 @@ class AlpsKnowledgeBrokerMPI : public AlpsKnowledgeBroker {
     /** Calculate the work quality and quantity on this process. */
     void updateWorkloadInfo();
 
+    virtual int getNumNodeLeftSystem()
+    { return static_cast<int>(systemWorkQuantity_); }
+    
     /** A worker donate its workload to the specified worker. */
     void donateWork(char*& buf, 
 		    int tag,
@@ -593,7 +593,7 @@ class AlpsKnowledgeBrokerMPI : public AlpsKnowledgeBroker {
     
     /** Destructor. */
     ~AlpsKnowledgeBrokerMPI();
-    
+
     /** Query the global rank of the process. */
     virtual int getProcRank() const { return globalRank_; }
 
@@ -631,10 +631,18 @@ class AlpsKnowledgeBrokerMPI : public AlpsKnowledgeBroker {
 
     /** @name Report search results. */
     //@{
-    /** The process queries the quality of the incumbent it stores. */
+    /** The process queries the quality of the incumbent this process stores. */
     virtual double getIncumbentValue() const {
+        double bestObj = ALPS_OBJ_MAX;
+        if (AlpsKnowledgeBroker::hasKnowledge(AlpsKnowledgeTypeSolution)) {
+	    bestObj = getBestKnowledge(AlpsKnowledgeTypeSolution).second;
+            if (incumbentValue_ > bestObj) {
+                return bestObj;
+            }
+        }
 	return incumbentValue_;
     }
+ 
     /** The master queries the quality of the best solution it knowns. */
     virtual double getBestQuality() const {
 	if (globalRank_ == masterRank_) {
@@ -650,6 +658,9 @@ class AlpsKnowledgeBrokerMPI : public AlpsKnowledgeBroker {
         }
     }
 
+    /** Get best estimalted quality in system. */
+    virtual double getBestEstimateQuality() { return systemWorkQuality_; }
+
     /** Master prints out the best solution that it knows. */
     virtual void printBestSolution(char* outputFile = 0) const;
 
